load("@ytt:data", "data")
load("@ytt:yaml", "yaml")
load("podvm_value_generator.star", "is_podvm_supported")
load("nw_value_generator.star", "get_network_provider")

# All the uTKG controllers need to use host network
def get_host_network():
    if is_podvm_supported():
        return False
    end
    return True
end

# Returns the node selector to be used for uTKG controllers
def get_node_selector():
    if is_podvm_supported():
        return None
    end
    return {
        "node-role.kubernetes.io/control-plane": "",
    }
end

# Returns the default tolerations used by uTKG controllers
def get_toleration():
    if is_podvm_supported():
        return []
    end
    return [
        {
            "effect": "NoSchedule",
            "key": "node-role.kubernetes.io/master",
            "operator": "Exists",
        },
        {
            "effect": "NoSchedule",
            "key": "node-role.kubernetes.io/control-plane",
            "operator": "Exists",
        },
        {
            "key": "CriticalAddonsOnly",
            "operator": "Exists",
        },
        {
            "effect": "NoExecute",
            "key": "node.alpha.kubernetes.io/notReady",
            "operator": "Exists",
        },
        {
            "effect": "NoExecute",
            "key": "node.alpha.kubernetes.io/unreachable",
            "operator": "Exists",
        },
        {
            "effect": "NoSchedule",
            "key": "kubeadmNode",
            "operator": "Equal",
            "value": "master",
        },
    ]
end

def get_yaml_data(data):
    return yaml.decode(yaml.encode(data))
end

def capabilities_package_values():
    values =  get_yaml_data(data.values.capabilitiesPackageValues)
    values["deployment"]["hostNetwork"] = get_host_network()
    values["deployment"]["nodeSelector"] = get_node_selector()
    values["deployment"]["tolerations"] = get_toleration()
    return values
end

def featuregates_package_values():
    values =  get_yaml_data(data.values.featureGatesPackageValues)
    values["deployment"]["hostNetwork"] = get_host_network()
    values["deployment"]["nodeSelector"] = get_node_selector()
    values["deployment"]["tolerations"] = get_toleration()
    return values
end

def tkr_service_package_values():
    values =  get_yaml_data(data.values.tkrServicePackageValues)
    values["deployment"]["hostNetwork"] = get_host_network()
    values["deployment"]["nodeSelector"] = get_node_selector()
    values["deployment"]["tolerations"] = get_toleration()
    return values
end

def addons_manager_package_values():
    values =  get_yaml_data(data.values.addonsManagerPackageValues)
    values["tanzuAddonsManager"]["deployment"]["hostNetwork"] = get_host_network()
    values["tanzuAddonsManager"]["deployment"]["nodeSelector"] = get_node_selector()
    values["tanzuAddonsManager"]["deployment"]["tolerations"] = get_toleration()
    values["tanzuAddonsManager"]["deployment"]["networkProvider"] = get_network_provider()
    return values
end

def tanzu_auth_package_values():
    values =  get_yaml_data(data.values.tanzuAuthPackageValues)
    values["deployment"]["hostNetwork"] = get_host_network()
    values["deployment"]["nodeSelector"] = get_node_selector()
    values["deployment"]["tolerations"] = get_toleration()
    return values
end
